DROP TABLE IF EXISTS `{{meeting}}`;
CREATE TABLE IF NOT EXISTS `{{meeting}}` (
  `mid` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '会议id',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '会议名称',
  `proposerid` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '申请人uid',
  `addtime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '添加时间',
  `mastertime` char(10) NOT NULL DEFAULT '' COMMENT '被实例化时间，格式（年月日）：2012-10-01',
  `masterid` mediumint(8) NOT NULL DEFAULT '0' COMMENT '被实例周期性会议的ID',
  `begin` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '开始时间',
  `end` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '结束时间',
  `instancetype` tinyint(2) NOT NULL DEFAULT '0' COMMENT '实例类型（1.循环主会议，2.循环实例） 0为非循环会议 ',
  `recurringtype` varchar(255) NOT NULL DEFAULT '' COMMENT '周期性会议类型(目前有week,month)',
  `recurringtime` varchar(255) NOT NULL DEFAULT '' COMMENT '周期性会议时间（每周几至及或每月几号）',
  `lastrecurring` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '最后一次生成的时间',
  `recurringrelate` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '关联的主实例id',
  `recurringbegin` int(10) unsigned NOT NULL  DEFAULT '0' COMMENT '周期性会议时间间隔_开始',
  `recurringend` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '周期性会议时间间隔_结束',
  `attendee` text NOT NULL COMMENT '出席者id',
  `deptid` text NOT NULL COMMENT '出席部门id',
  `positionid` text NOT NULL COMMENT '出席岗位id',
  `roleid` text NOT NULL COMMENT '出席角色id',
  `actualattendee` text NOT NULL COMMENT '实际出席者id',
  `host` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '主持人uid',
  `recorderid` mediumint(8) unsigned NOT NULL  DEFAULT '0' COMMENT '纪要员uid',
  `outside` varchar(255) NOT NULL DEFAULT '' COMMENT '外部出席会议者',
  `actualoutside` text NOT NULL COMMENT '实际外部出席会议者',
  `topic` varchar(255) NOT NULL  DEFAULT '' COMMENT '主要议题',
  `attachmentid` text NOT NULL COMMENT '附件ID',
  `note` text NOT NULL COMMENT '备注',
  `roomid` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '会议室',
  `roomdevice` varchar(255) NOT NULL DEFAULT '' COMMENT '会议室设备',
  `status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '会议状态(0：待批 1：批准  2：不批准 3：已结束,4:已归档 5:已经删除)',
  `absent` text NOT NULL COMMENT '缺席人员',
  `reason` varchar(255) NOT NULL DEFAULT '' COMMENT '退回理由',
  `currentstep` tinyint(1) NOT NULL DEFAULT '0' COMMENT '当前审核步骤，根据meeting_approval和approval对比得出来的，一般情况都是前者表里对应mid的最大的step字段大1的值，成功或者免审核都是0',
  PRIMARY KEY (`mid`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `{{meeting_minutes}}`;
CREATE TABLE IF NOT EXISTS `{{meeting_minutes}}` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '流水id',
  `mid` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '会议id',
  `reader` varchar(255) NOT NULL DEFAULT '' COMMENT '指定读者',
  `content` text NOT NULL COMMENT '会议纪要正文',
  `attachmentid` varchar(255) NOT NULL DEFAULT '' COMMENT '附件id',
  `uid` mediumint(8) NOT NULL DEFAULT '0' COMMENT '添加人uid',
  `addtime` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '添加时间',
  `commentcount` int(10) unsigned NOT NULL DEFAULT '0' COMMENT '评论数量',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `{{meeting_room}}`;
CREATE TABLE IF NOT EXISTS `{{meeting_room}}` (
  `id` mediumint(6) unsigned NOT NULL AUTO_INCREMENT COMMENT '会议室id',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '会议室名称',
  `admin` varchar(20) NOT NULL DEFAULT '' COMMENT '管理员id',
  `typecode` char(50) NOT NULL DEFAULT '' COMMENT '会议室类型',
  `aid` smallint(6) unsigned NOT NULL DEFAULT '0' COMMENT '审批流程id',
  `capacity` mediumint(6) unsigned NOT NULL DEFAULT '0' COMMENT '座位数',
  `applyday` varchar(20) NOT NULL DEFAULT '' COMMENT '可申请周期',
  `uids` text NOT NULL COMMENT '权限uid串',
  `deptids` text NOT NULL COMMENT '权限deptid串',
  `roles` text NOT NULL COMMENT '权限roles串',
  `positions` text NOT NULL COMMENT '岗位维度权限 ID 字符串',
  `location` varchar(255) NOT NULL DEFAULT '' COMMENT '所在地点',
  `desc` text NOT NULL COMMENT '会议室描述',
  `device` varchar(255) NOT NULL DEFAULT '' COMMENT '设备情况',
  `imgattach` int(11) NOT NULL DEFAULT '0' COMMENT '图片附件',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `{{meeting_room_device}}`;
CREATE TABLE IF NOT EXISTS `{{meeting_room_device}}` (
  `id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT '流水id',
  `name` varchar(255) NOT NULL DEFAULT '' COMMENT '设备名称',
  `icon` varchar(255) NOT NULL DEFAULT '' COMMENT '图标',
  `status` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT '状态，0禁用，1启用',
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `{{meeting_approval}}`;
CREATE TABLE IF NOT EXISTS `{{meeting_approval}}` (
  `id` mediumint(8) unsigned NOT NULL AUTO_INCREMENT COMMENT '流水id',
  `mid` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '会议id',
  `uid` mediumint(8) unsigned NOT NULL DEFAULT '0' COMMENT '签收人id',
  `step` varchar(10) NOT NULL DEFAULT '' COMMENT '签收步骤(1,2,3,4,5对应approval表level1,level2,level3,level4,level5)',
  PRIMARY KEY (`id`),
  KEY `MID` (`mid`) USING BTREE
) ENGINE=MyISAM DEFAULT CHARSET=utf8;

INSERT INTO `{{notify_node}}`(`node`, `nodeinfo`, `module`, `titlekey`, `contentkey`, `sendemail`, `sendmessage`, `sendsms`, `type`) VALUES ('meeting_new_message','会议室申请提醒','meeting','meeting/default/New meeting title','meeting/default/New meeting content','1','1','1','2');
INSERT INTO `{{notify_node}}`(`node`, `nodeinfo`, `module`, `titlekey`, `contentkey`, `sendemail`, `sendmessage`, `sendsms`, `type`) VALUES ('meeting_agree_message','同意会议室申请提醒','meeting','meeting/default/Agree title','meeting/default/Agree content','1','1','1','2');
INSERT INTO `{{notify_node}}`(`node`, `nodeinfo`, `module`, `titlekey`, `contentkey`, `sendemail`, `sendmessage`, `sendsms`, `type`) VALUES ('meeting_refused_message','拒绝会议室申请提醒','meeting','meeting/default/Refused title','meeting/default/Refused content','1','1','1','2');
INSERT INTO `{{notify_node}}`(`node`, `nodeinfo`, `module`, `titlekey`, `contentkey`, `sendemail`, `sendmessage`, `sendsms`, `type`) VALUES ('meeting_push_message','会议室催办提醒','meeting','meeting/default/Push title','meeting/default/Push content','1','1','1','2');
INSERT INTO `{{notify_node}}`(`node`, `nodeinfo`, `module`, `titlekey`, `contentkey`, `sendemail`, `sendmessage`, `sendsms`, `type`) VALUES ('meeting_minutes_message','会议纪要消息提醒','meeting','meeting/default/New minutes title','meeting/default/New minutes content','1','1','1','2');
INSERT INTO `{{notify_node}}`(`node`, `nodeinfo`, `module`, `titlekey`, `contentkey`, `sendemail`, `sendmessage`, `sendsms`, `type`) VALUES ('meeting_join_message','会议提醒','meeting','meeting/default/Join meeting title','meeting/default/Join meeting content','1','1','1','2');
INSERT INTO `{{nav}}`(`pid`, `name`, `url`, `targetnew`, `system`, `disabled`, `sort`, `module`) VALUES ('5','会议管理','meeting/manager/index','0','1','0','4','meeting');
INSERT INTO `{{menu_common}}`( `module`, `name`, `url`, `description`, `sort`, `iscommon`) VALUES ('meeting','会议','meeting/manager/index','提供企业工作会议管理','15','0');
INSERT INTO `{{menu}}`(`name`, `pid`, `m`, `c`, `a`, `param`, `sort`, `disabled`) VALUES ('会议管理','0','meeting','dashboard','index','','0','0');
INSERT INTO `{{cron}}` (`available`, `type`,`module`, `name`, `filename`, `lastrun`, `nextrun`, `weekday`, `day`, `hour`, `minute`) VALUES ( '1', 'system','meeting', '每日实例化周期性会议', 'CornMeetingAutoGenerate.php', '1438358400', '1438444800', '-1', '-1', '0', '0');
REPLACE INTO `{{setting}}`(`skey`, `svalue`) VALUES('meetingconfig', 'a:8:{s:15:"requireattendee";i:1;s:15:"requirerecorder";i:0;s:11:"requirehost";i:0;s:7:"outside";i:0;s:12:"skipconflict";i:0;s:12:"requiretopic";i:0;s:10:"opendevice";i:1;s:11:"roommanager";s:1:"1";}');
REPLACE INTO `{{setting}}`(`skey`, `svalue`) VALUES('meetingworkingtime', '8,18');


INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '1', '投影幕', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '2', '录音笔', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '3', '音响', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '4', '投影仪', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '5', '笔记本电脑', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '6', '麦克风', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '7', '无线网络', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '8', '摄像机', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '9', '相机', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '10', '白板', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '11', '有线网络', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '12', '座位牌', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '13', '茶水', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '14', '横幅', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '15', '水果', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '16', '显示屏', '', '1');
INSERT INTO `{{meeting_room_device}}` ( `id`, `name`, `icon`, `status` ) VALUES ( '17', '文具', '', '1');
