
$(function(){
	var Meeting = {
		op: {
			/**
			 * 审批通过
			 * @method  verifyMeeting
			 * @param  {Object} param 传入JSON格式数据
			 * @return {Object}       返回deffered对象
			 */
			"verifyMeeting": function(param){
				var url = Ibos.app.url("meeting/restmanager/put",{'op' : 'pass'});
				return $.post(url, param, $.noop, "json");
			},
			/**
			 * 退回会议室申请
			 * @method  returnMeeting
			 * @param  {Object} param status, mid 分类和会议室申请id
			 * @return {Object}       返回deffered对象
			 */
			"returnMeeting": function(param){
				var url = Ibos.app.url("meeting/restmanager/put",{'op' : 'back'});
				return $.post(url, param, $.noop, "json");
			},
			/**
			 * 删除会议室申请
			 * @method  deleteMeeting
			 * @param  {Object} param status, mid 分类和会议室申请id
			 * @return {Object}       返回deffered对象
			 */
			"deleteMeeting": function(param){
				var url = Ibos.app.url('meeting/restmanager/delete',{'op' : 'getAudits'});
				return $.post(url, param, $.noop, "json");
			},
			/**
			 * 重新申请会议室
			 * @method  adoptMeeting
			 * @param  {Object} param status, mid 分类和会议室申请id
			 * @return {Object}       返回deffered对象
			 */
			"adoptMeeting": function(param){
				var url = Ibos.app.url("meeting/manager/restapply");
				return $.post(url, param, $.noop, "json");
			},
			/**
			 * 获取会议室申请数据
			 * @method  getMeetingInfo
			 * @param  {Object} param status, mid 分类和会议室申请id
			 * @return {Object}       返回deffered对象
			 */
			// 情况1(默认), param: status；
			// 情况2(翻页), param: status, page
			// 情况3(搜索), param: status, keywords 第三种情况待定
			"getMeetingInfo": function(param){
				var url = Ibos.app.url("meeting/restmanager/get",{'op' : 'getAudits'});
				return $.get(url, param, $.noop, "json");
			},
			/**
			 * 搜索, 通过关键字和分类标示获取会议室申请数据
			 * @method  getMeetingInfo
			 * @param  {Object} param keyords, status
			 * @return {Object}       返回deffered对象
			 */
			"getMeetingInfoByKeywords": function(param){
				var url = "";
				return $.post(url, param, $.noop, "json");
			}
		},
		/**
		 * 清除绑定在每项item上的数据
		 * @method clearMeetingItem
		 * @param  {Object} $container 传入Jquery节点对象
		 */
		"clearMeetingItem": function($container){
			$container.find("li").each(function(){
				clearInterval($(this).data("interval"));
			});
		},
		/**
		 * 渲染会议室列表视图
		 * @method renderMeetingView
		 * @param  {Object} $container 传入jquery节点对象
		 * @param  {String} tpl        传入模板ID
		 * @param  {Object} param      传入JSON格式数据
		 */
		"renderMeetingView": function($container, tpl, param){
			var _this = this,
				status = param.status;
			// 先解除绑定在每项item上的setinterval的数据
			_this.clearMeetingItem($container);

			var keywords = Ibos.app.g("keywords"),
				param = keywords ? $.extend(param, {keywords: keywords}) : param;

			//生成遮罩
			$mainer.waiting(null, "normal", true);
			_this.op.getMeetingInfo(param).done(function(res){
				var data = res.meetings,
					pages = res.pages;

				//清空container
				$container.empty();
				$.each(data, function(index, val){
					var itemData = this,
						$elem = _this.creatMeetingItem(itemData, tpl, status);
					$container.append($elem);
				});

				_this.initPagination(pages, status);

				_this.refreshStatusTip(res);

				_this.refreshNavActiveStatus(param);

				Meeting.refreshNavStatusCount(res.tabNum);
				//初始化冲突信息提示
				$(".warning-tip").tooltip();
				//去掉遮罩
				setTimeout(function(){
					$mainer.waiting(false);
				}, 1010);
			});
		},
		/** 
		 * "待审核",根据时间变化时, 每项item的功能按钮以及视图的变化
		 * @method  changePeendingMeetingView
		 * @param  {Number} start  开始时间
		 * @param  {Number} end    结束时间
		 * @param  {Object} $elem  传入Jquery节点对象
		 */
		"changePeendingMeetingView": function(start, end, $elem){
			var $info = $elem.find(".detailed-info"),
				$adoptBtn = $info.find(".opt-adopt-btn"),
				$meetingName = $info.find(".meeting-title"), 
				now = parseInt((new Date().getTime()) / 1000);
			if(start - now >= 0){
				$info.addClass("nostart");
			}else{
				$info.removeClass("nostart").addClass("ended");
				$adoptBtn.hide();
				$meetingName.removeClass("xcbu");
			}	
		},
		/** 
		 * 已通过"分类,根据时间变化时, 每项item的功能按钮以及视图的变化
		 * @method  changeAdoptMeetingView
		 * @param  {Number} start  开始时间
		 * @param  {Number} end    结束时间
		 * @param  {Object} $elem  传入Jquery节点对象
		 */
		"changeAdoptMeetingView": function(start, end, $elem){
			var now = parseInt((new Date().getTime()) / 1000),
				$contentWrap = $elem.find(".meeting-item"),
				$nogoing = $elem.find(".status-nogoing"),
				$going = $elem.find(".status-going"),
				// 倒计时内容
				$timewrap = $going.find(".meeting-last-time"),
				// 当前会议状态，分为未开始 进行中 已结束
				$statusWrap = $elem.find(".mp-status-wrap"),
				$statusTip = $statusWrap.find("i"),
				//功能按钮
				$returnBtn = $elem.find('.opt-return-btn'),
				//会议名称
				$meetingTitle = $contentWrap.find(".meeting-title");
			if(end - now >= 0){
				if(now < start){
					$contentWrap.addClass("nostart");
					// 根据会议状态，改变会议状态标识
					$statusTip.removeClass("on-normal-goning").addClass("on-normal-nostart");
				}

				if(now > start && now < end){
					// 当会议在进行中时，改变会议状态
					$contentWrap.removeClass("nostart").addClass("going");
					//将会议时间由日期区间切换到倒计时状态
					$nogoing.hide();
					$going.show();
					//开始倒计时
					Meeting.fun.timeCount(start, end, now, $timewrap);
					// 改变右上角的会议状态标识
					$statusTip.removeClass("on-normal-nostart").addClass("on-normal-goning");
					//当会议进行中时，隐藏退回的功能栏
					$returnBtn.hide();
				}
			}else{
				// 当会议结束时，改变会议状态
				$contentWrap.removeClass("going").addClass("ended");
				//当会议结束时，改变会议状态标识
				$statusTip.removeClass();
				// 切换会议倒计时状态到会议时间区间形式
				$nogoing.show();
				$going.hide();
				
				$meetingTitle.removeClass("xcbu");
				//当会议进行中时，隐藏退回的功能栏
				$returnBtn.hide();
			}
		},	
		/** 
		 * "被拒绝"分类,根据时间变化时, 每项item的功能按钮以及视图的变化
		 * @method  changeRefuseMeetingView
		 * @param  {Number} start  开始时间
		 * @param  {Number} end    结束时间
		 * @param  {Object} $elem  传入Jquery节点对象
		 */
		"changeRefuseMeetingView": function(start, end, $elem){
			var $info = $elem.find(".detailed-info"),
				$adoptBtn = $info.find(".opt-adopt-btn"),
				$meetingName = $info.find(".meeting-title"), 
				now = parseInt((new Date().getTime()) / 1000);
			if(start - now >= 0){
				$info.addClass("nostart");
			}else{
				$info.removeClass("nostart").addClass("ended");
				$adoptBtn.hide();
				$meetingName.removeClass("xcbu");
			}
		}
	};

	$.extend(true, Meeting, MeetingCommon);


	var $mainer = $("#mm_list_mainer"), 
		$container = $("#meeting_list_wrap"),
		isReturn = Ibos.app.g("isReturn"),
		currStatus = Ibos.app.g("status"),
		$unapprovedNum = $("#unapproved_num"),
		$passedNum = $("#passed_num"),
		$backedNum = $("#backed_num"),
		tpl = Meeting.selectTemplateByStatus(isReturn ? currStatus : 0),
		status = isReturn ? currStatus : 0,
		param = {status: status};
		
	Meeting.renderMeetingView($container, tpl, param);

	//搜索功能
	$("#mn_search").search(function(value){
       var $active = $("#review_type_nav>li.active"),
       		status = $active.data("param").status,
       		tpl = Meeting.selectTemplateByStatus(status),
       		param = {status: status, keywords: value};
       	Ibos.app.s({"keywords": value});
   		Meeting.renderMeetingView($container, tpl, param);
    });

	Ibos.evt.add({
    	// 切换"待审核", "已通过", "已拒绝"三种分类
		"switchTab": function(param, elem){
			var $this = $(this),
				$lis = $this.closest("ul").find("li"),
				status = param.status,
				tpl = Meeting.selectTemplateByStatus(status),
				param = {status: status};
			$lis.removeClass("active");
			$this.addClass("active");
			Ibos.app.s({"keywords": ""});
			Meeting.renderMeetingView($container, tpl, param);
		},
		"adoptMeeting": function(param, elem, evt){
			var $this = $(this),
				$currli = $this.closest("li");
			Meeting.op.adoptMeeting(param).done(function(res){
				if(res.isSuccess){
					var pages = res.pages;
					$currli.remove();
					Meeting.refreshMeetingView(page.curPage, param.status);
					window.location.href= res.url;
				}
				Ui.tip(res.msg, res.isSuccess ? "" : "danger");
			});
			evt.stopPropagation();
		},
		// 审批通过
		"verifyMeeting": function(param, elem, evt){
			Meeting.op.verifyMeeting(param).done(function(res){
				res.isSuccess && window.location.reload();
				Ui.tip(res.msg, res.isSuccess ? "" : "danger");
			});
			evt.stopPropagation();
		},
		// 退回功能
		// 被退回的会议申请，将在"我的会议"的"被拒绝"里面显示
		"returnMeeting": function(param, elem, evt){
			var $this = $(this),
				$currli = $this.closest("li");
			Ui.dialog({
				title: Ibos.l("MEETING.BACK"),
				id: "r_dialog",
				content: document.getElementById("rollback_reason"),
				ok: function(){
					var $reason = $("#rollback_textarea"), 
						reason = $reason.val();
					if(reason){
						param = $.extend({reason: reason}, param);
						$mainer.waiting(null, "normal", true);
						Meeting.op.returnMeeting(param).done(function(res){
							if(res.isSuccess){
								var pages = res.data.pages;
								$currli.remove();
								$reason.val("");
								Meeting.refreshMeetingView(pages.curPage, res.data.status);
							}
							Ui.tip(res.msg, res.isSuccess ? "" : "danger");
							$mainer.waiting(false);
						});
					}else{
						Ui.tip(Ibos.l("MEETING.INPUT_BACK_REASON"), "warning");
						return false;
					}
				}
			});	
			evt.stopPropagation();
		},
		// 删除会议申请
		"deleteMeeting": function(param, elem, evt){
			var $this = $(this),
				$currli = $this.closest("li");
			Ui.confirm(Ibos.l("MEETING.DELETE_MEETING_CONFIRM"), function(){
				$mainer.waiting(null, "normal", true);
				Meeting.op.deleteMeeting(param).done(function(res){
					if(res.isSuccess){
						var pages = res.data.pages;
						$currli.remove();
						Meeting.refreshMeetingView(pages.curPage, res.data.status);
						Meeting.refreshNavStatusCount(res.data.tabNum);
					}
					Ui.tip(res.msg, res.isSuccess ? "" : "danger");
					$mainer.waiting(false);
				});
			}); 
			evt.stopPropagation();
		}
	});
});
