var MeetingCommon = {
	fun : {
		/**
		 * 进行倒计时
		 * @method  timeCount
		 * @param  {Number} start 开始时间
		 * @param  {Number} end   结束时间
		 * @param  {Number} now   现在时间
		 * @param  {Object} $elem 传入jquery节点对象
		 */
		"timeCount": function(start, end, now, $elem){
			if(now > start && now < end){
				var count = parseInt(end - now),
					hours = parseInt(count / 60 / 60),
					fhours = hours >= 10 ? hours : "0" + hours,
					minute = parseInt(count / 60 % 60),
					fminute = minute >= 10 ? minute : "0" + minute,
					seconds = parseInt(count % 60),
					fseconds = seconds >= 10 ? seconds : "0" + seconds; 
			}
			$elem.text(fhours + ":" + fminute + ":" + fseconds);	
		}
	},
	/**
	 * 初始化页码
	 * @method initPagination
	 * @param  {Object} pages  传入JSON格式页面参数
	 * @param  {Number} status 传入状态值
	 */
	"initPagination": function(pages, status){
		var _this = this;
		// 初始化页码
		var _settings = {
			items_per_page: pages.limit,
			current_page: pages.curPage,
			num_display_entries: 5,
			prev_text: false,
			next_text: false,
			renderer: "ibosRenderer",
			allow_jump: true,
			load_first_page: false,
			callback: function(page, elem) {
				page = page + 1;
				_this.refreshMeetingView(page, status);
			}
		};
		$("#mt_pagination").pagination(pages.count, _settings);
	},
	/**
	 * 当点击不同分类时，对应分类("待审核","已通过", "被拒绝")下的提示不同，刷新提示
	 * @method description
	 * @param  {Object} param 传入JSON格式数据
	 */
	"refreshStatusTip": function(param){
		var status = param.status,
			$markWrap = $(".meeting-status-tip"),
			$tipContent = $markWrap.eq(param.status);
		$markWrap.hide();
		$tipContent.show();
		if(status == 0){	
			$tipContent.find(".conf-num-tip").text(param.conflictsNum);
		}else if(status == 1){
			$tipContent.find(".unstarted-num-tip").text(param.unStarted);
			$tipContent.find(".ongoing-num-tip").text(param.onGoing);
		}
	},
	/**
	 * 通过status获取对应的模板id
	 * @method selectTemplateByStatus
	 * @param  {Number} status 传入状态值
	 * @return {String}        返回模板id
	 */
	"selectTemplateByStatus": function(status){
		var tpl;
		switch(status){
			case 0:
				tpl = "review";
				break;
			case 1:
				tpl = "adopt";
				break;
			case 2:
				tpl = "refuse";
				break;
		}
		return "meeting_"+ tpl +"_tpl";
	},
	/**
	 * 通过status刷新导航的活动状态
	 * @method refreshNavActiveStatus
	 * @param  {Object} param 传入JSON格式数据
	 */
	"refreshNavActiveStatus": function(param){
		var status = param.status,
			$ul = $mainer.find(".review-nav-skid");
		$ul.children().removeClass("active").eq(status).addClass("active");
	},
	/**
	 * refreshNavStatusCount
	 * @method refreshNavStatusCount
	 * @param  {Object} param 传入JSON格式数据
	 */
	"refreshNavStatusCount": function(param){
		var unapprovedNum = param.unapprovedNum,
			passedNum = param.passedNum,
			backedNum = param.backedNum;
		$unapprovedNum.text(unapprovedNum);
		$passedNum.text(passedNum);
		$backedNum.text(backedNum);
	},
	/**
	 * 刷新会议页面
	 * @method refreshMeetingView
	 * @param  {String} pages  传入页面参数
	 * @param  {Number} status 传入状态值
	 */
	"refreshMeetingView": function(page, status){
		var _this = this,
			param = {page: page, status: status},
			tpl = _this.selectTemplateByStatus(status);

		_this.renderMeetingView($container, tpl, param);
	},
	/**
	 * 根据时间推移，调整功能按钮以及视图的变化
	 * @method changeMeetingView
	 * @param  {Number} start  开始时间
	 * @param  {Number} end    结束时间
	 * @param  {Object} $elem  传入Jquery节点对象
	 * @param  {Number} status 传入状态值
	 */
	"changeMeetingView": function(start, end, $elem, status){
		var _this = this,
			fun;
		switch(status){
			case 0:
				fun = "changePeendingMeetingView";
				break;
			case 1:
				fun = "changeAdoptMeetingView";
				break;
			case 2:
				fun = "changeRefuseMeetingView";
				break;
		}
		_this[fun](start, end, $elem);
	},
	/**
	 * 生成每项会议室申请item
	 * @method  creatMeetingItem
	 * @param  {Object} data   传入JSON格式数据
	 * @param  {String} tpl    模板ID
	 * @param  {Number} status 传来状态值
	 * @return {Object}        返回jquery节点对象
	 */
	"creatMeetingItem": function(data, tpl, status, index){
		var _this = this;
		var tplData = {data: data};
		var	elem = $.template(tpl, tplData);

		var $elem = $(elem);
		$elem.interval = setInterval(function(){
				var param = $elem.find(".time-stemp").data("param"),
					start = param.start,
					end = param.end;
				_this.changeMeetingView(start, end, $elem, status);
			}, 1000);
		$elem.data("interval"+ index, $elem.interval);
		return $elem;
	},
	/**
	 * 清除绑定在每项item上的数据
	 * @method clearMeetingItem
	 * @param  {Object} $container 传入Jquery节点对象
	 */
	"clearMeetingItem": function($container){
		$container.find("li").each(function(index){
			clearInterval($(this).data("interval"+ index));
		});
	}
};

var $mainer = $("#mm_list_mainer"),
	$container = $("#meeting_list_wrap"),
	$unapprovedNum = $("#unapproved_num"),
	$passedNum = $("#passed_num"),
	$backedNum = $("#backed_num");


$(function(){
	

    Ibos.evt.add({
		//查看对应会议室申请的详情
		"showDetailedInfo": function(param, elem){
			var url = $(this).data("url");
			window.location.href = url;
		}
    });
});
