$(function() {
    var Meeting = {
        regExp: {
            "timeYMD": /^(\d{4})-(0\d{1}|1[0-2])-(0\d{1}|[12]\d{1}|3[01])$/,
            "timeMS": /^(0\d{1}|1\d{1}|2[0-3]):([0-5]\d{1})$/,
            "outside": /^[\u4e00-\u9fa5a-zA-Z]+?$/
        },
        template: {
            // 会议室设备模板
            "equipmentItem": '<% for(var i = 0; i < data.length; i++ ) { %>' +
                '<li data-action="selectEquipment" <% if(data[i][0].isSelected) { %>class="active" <% } %>>' +
                '<i class="o-equit-<%= data[i].id %>"></i>' +
                '<p class="title"><%= data[i].name %></p>' +
                '<input type="checkbox" name="roomdevice[]" value="<%= data[i].id %>" <% if(data[i][0].isSelected) { %> checked <% } %>>' +
                '</li>' +
                '<% } %>'
        },
        op: {
            /**
             * 获取会议室信息
             * @method getRoomInfo
             * @param  {String} roomid 传入会议室的id
             * @param  {String} mid    
             * @return {Object}        返回deffered对象
             */
            "getRoomInfo": function(roomid, mid) {
                var url = Ibos.app.url('meeting/restroom/get'),
                    param = { id: roomid, mid: mid, op: 'getRoom' };
                return $.get(url, param, $.noop, "json");
            },
            /**
             * 获取预约信息
             * @method getAppointmentInfo
             * @param  {String} roomid 传入会议室的id
             * @return {Object}        返回deffered对象
             */
            "getAppointmentInfo": function(roomid) {
                var url = Ibos.app.url('meeting/restroom/get'),
                    param = { id: roomid, op: 'getAppointment' };
                return $.get(url, param, $.noop, "json");
            },
            /**
             * 获取冲突信息
             * @method getConflictInfo
             * @param  {String} roomid    传入会议室的id
             * @param  {Number} startTime 开始时间
             * @param  {Number} endTime   结束时间
             * @return {Object}           返回deffered对象
             */
            "getConflictInfo": function(roomid, startTime, endTime) {
                var url = Ibos.app.url('meeting/restroom/get', { 'op': 'showConflict' }),
                    param = { id: roomid, start: startTime, end: endTime };
                return $.get(url, param, $.noop, "json");
            },
            /**
             * 通过周期性数据获取冲突信息
             * @method getConflictInfoByLoop
             * @param  {Number} param 传入JSON格式数据
             * @return {Object}       返回deffered对象
             */
            "getConflictInfoByLoop": function(param) {
                var url = Ibos.app.url('meeting/restroom/get', { 'op': 'getConflictInfoByLoop' });
                return $.get(url, param, $.noop, "json");
            }
        },
        /**
         * 更新会议室信息
         * @method refreshRoomInfo
         * @param  {String} roomid 传入会议室的id
         * @param  {String} mid    
         */
        "refreshRoomInfo": function(roomid, mid) {
            var that = this;
            $contentRight.waiting(null, "normal", true);
            that.op.getRoomInfo(roomid, mid).done(function(res) {
                var itemTpl = that.template.equipmentItem,
                    data = res.device,
                    items = $.template(that.template.equipmentItem, { data: data });
                //更换会议室图片
                $("#room_view").attr("src", res.img);
                //更换会议室预约数
                $("#appointment_num").text(res.appointmentCount);
                //更新会议室设备列表
                $("#equipment_list").empty().append(items);
                //更新会议室座位数
                $("#seats_num").text(res.capacity);
                //更新会议室类型
                $("#room_type").text(res.typecode);
                //更新会议室管理员
                $("#room_manager").text(res.admin);
                //更新会议室地址
                $("#room_address").text(res.location);
                $contentRight.waiting(false);
            });
        },
        /**
         * 更新冲突信息
         * @method setLoopTime
         * @param  {String} $roomid    传入房间ID
         * @param  {Object} $startTime 开始时间jquery节点对象
         * @param  {Object} $endTime   结束时间jquery节点对象
         */
        "refreshConflictInfo": function(roomid, startTime, endTime) {
            var that = this;
            $contentLeft.waiting(null, "normal", true);
            that.op.getConflictInfo(roomid, startTime, endTime).done(function(res) {
                //更新可预约状态
                $("#reserve_status_wrap .status").hide().eq(res.status).show();
                // 改变预约状态
                $("#reserve_status_input").val(res.status);
                $contentLeft.waiting(false);
            });
        },
        /**
         * 加载冲突信息
         * @method loadConflictInfo
         * @param  {String} roomid 传入会议室ID
         */
        "loadConflictInfo": function(roomid) {
            var that = this,
                start = $("#start_time input").val(),
                end = $("#end_time input").val();
            (start && end) && that.refreshConflictInfo(roomid, start, end);
        },
        /**
         * 初始化表单信息
         * @method initFormInfo
         */
        "initFormInfo": function() {
            var that = this,
                roomid = $("#roomid").val(),
                mid = $("#mid").val(),
                url = window.location.href;
            that.refreshRoomInfo(roomid, mid);
            Ibos.app.g("isDefaultApply") && that.loadConflictInfo(roomid);
        },
        /**
         * 设置重复的节点
         * @method setRepeatSelect
         * @param  {String} type 传入类型
         */
        "setRepeatSelect": function(type) {
            $("[data-node-type='" + type + "']").show().siblings().hide();
        },
        /**
         * 设置周期性申请默认时间
         * @method setLoopTime
         * @param  {Object} $startTime 开始时间jquery节点对象
         * @param  {Object} $endTime   结束时间jquery节点对象
         */
        "setLoopTime": function($startTime, $endTime) {
            var that = this,
                startTime = moment().toDate(),
                endTime = moment().add(30, "m").toDate();
            // 初始化开始时间及结束时间， 默认为当前时间至30分钟后
            $startTime.datetimepicker("setLocalDate", startTime).on("changeDate", function(evt) {
                //根据周期性申请时间，判断是否冲突
                that.checkConflictByLoop();
            });
            $endTime.datetimepicker("setLocalDate", endTime).on("changeDate", function(evt) {
                //根据周期性申请时间，判断是否冲突
                that.checkConflictByLoop();
            });
        },
        /**
         * 通过类型获取对应的数据，这里的周期性类型为"周"和"月"
         * @method getLoopDataByType
         * @param  {String}       type 传入要获取的类型
         * @return {Array|String}      返回类型数据
         */
        "getLoopDataByType": function(type) {
            var $wrap = $("[data-node-type='" + type + "']"),
                data;
            if (type == "week") {
                var $activeBtns = $wrap.find(".btn.active"),
                    selectArray = [];
                $.each($activeBtns, function(i, v) {
                    var $this = $(this),
                        value = $this.find("[name='applyday[]']").val();
                    selectArray.push(value);
                });
                data = selectArray;
            } else if (type == "month") {
                data = $wrap.find(".month-repeat-select").val();
            }
            return data;
        },
        /**
         * 根据周期性申请时间，判断是否冲突
         * @method checkConflictByLoop
         */
        "checkConflictByLoop": function() {
            var that = this,
                type = $("#repeat_type").val(),
                data = that.getLoopDataByType(type),
                dateRange = $("#recurring_daterange_input").val(),
                startTime = $("#recurring_start_time").val(),
                endTime = $("#recurring_end_time").val(),
                roomid = $("#roomid").val(),
                param = {
                    id: roomid,
                    type: type,
                    data: data,
                    dateRange: dateRange,
                    start: startTime,
                    end: endTime
                };
            if (dateRange && startTime && endTime) {
                $contentLeft.waiting(null, "normal", true);
                that.op.getConflictInfoByLoop(param).done(function(res) {
                    if (res.isSuccess) {
                        //更新可预约状态
                        $("#reserve_status_wrap .status").hide().eq(res.status).show();
                        // 改变预约状态
                        $("#reserve_status_input").val(res.status);
                    } else {
                        Ui.tip(res.msg, "danger");
                    }
                    $contentLeft.waiting(false);
                });
            }
        },
        /**
         * 外部参会人员验证
         * @method outsideVaildator
         * @param  {String}         text 传入外部参会人员
         * @return {Boolean|String}      返回是否验证成功
         */
        "outsideVaildator": function(text) {
            var _this = this,
                reg = _this.regExp.outside,
                text = text.split(/;|；|,|，|、| /);
            for (var i = 0; i < text.length; i++) {
                if (!reg.test(text[i])) text.splice(i, 1);
            }
            return text.join(",").length > 0 ? true : "请输入正确的格式,并以逗号隔开";
        },
        "applydayValidator": function() {
            if ($('#recurring_switch').is(':checked')) {
                var ret = [];
                $('[name="applyday[]"]').each(function(i, e) {
                    e.checked && ret.push(i);
                });
                if (ret.length === 0) return false;
            }
            return true;
        }
    };

    var $contentLeft = $("#room_info_left"),
        $contentRight = $("#room_info_right"),
        insideIsNecessary = Ibos.app.g("insideIsNecessary"),
        outsideIsNecessary = Ibos.app.g("outsideIsNecessary"),
        hostIsNecessary = Ibos.app.g("hostIsNecessary"),
        recorderIsNecessary = Ibos.app.g("recorderIsNecessary"),
        topicIsNecessary = Ibos.app.g("topicIsNecessary"),
        isIgnoreConflict = Ibos.app.g("isIgnoreConflict");

    $.formValidator.initConfig({
        formID: "apply_room_form",
        errorFocus: true
    });

    $("#meeting_name").formValidator()
        .regexValidator({
            regExp: "notempty",
            dataType: "enum",
            onError: Ibos.l("MEETING.ROOM_TITLE_EMPTY")
        });

    // 根据后台设置，会议室议题是否为必填项
    if (topicIsNecessary) {
        $("#meeting_topic").formValidator()
            .regexValidator({
                regExp: "notempty",
                dataType: "enum",
                onError: Ibos.l("MEETING.MEETING_TITLE_EMPTY")
            });
    }

    $("#start_time input").formValidator({
            relativeID: "begin",
            onFocus: Ibos.l("MEETING.SELECT_STARTTIME")
        }).regexValidator({
            regExp: "notempty",
            dataType: "enum",
            onError: Ibos.l("MEETING.STARTTIME_EMPTY")
        });


    $("#end_time input").formValidator({
            relativeID: "end",
            onFocus: Ibos.l("MEETING.SELECT_ENDTIME")
        }).regexValidator({
            regExp: "notempty",
            dataType: "enum",
            onError: Ibos.l("MEETING.STARTTIME_EMPTY")
        });

    $("#cycle_group_wrap").formValidator()
        .functionValidator({
            fun: function(txt, elem) {
                return Meeting.applydayValidator();
            },
            onError: Ibos.l("MEETING.APPLY_DAY_EMPTY")
        })

    // 根据后台设置，内部参会人员是否必填
    if (insideIsNecessary) {
        $("#attend_number").formValidator({
                relativeID: "attend_wrap",
                onFocus: Ibos.l("MEETING.SELECT_ATTEND")
            })
            .regexValidator({
                regExp: "notempty",
                dataType: "enum",
                onError: Ibos.l("MEETING.ATTEND_EMPTY")
            })
            .on("change", function() { $(this).trigger("blur"); });
    }

    // 根据后台设置，外部参会人员是否必填

    if (outsideIsNecessary) {
        $("#outside_attendee").formValidator({
            onFocus: Ibos.l("MEETING.OUTATTEND_FORMAT")
        }).functionValidator({
            fun: function(txt, elem) {
                return Meeting.outsideVaildator(txt);
            },
            onError: Ibos.l("MEETING.OUTATTEND_EMPTY")
        });
    } else {
        $("#outside_attendee").formValidator({
            empty: true,
            onFocus: Ibos.l("MEETING.OUTATTEND_FORMAT")
        }).functionValidator({
            fun: function(txt, elem) {
                return Meeting.outsideVaildator(txt);
            },
            onError: Ibos.l("MEETING.INPUT_OUTATTEND_FORMAT")
        });
    }


    //根据后台设置，会议主持人是否必填
    if (hostIsNecessary) {
        $("#meeting_host").formValidator({
                relativeID: "host_wrap",
                onFocus: Ibos.l("MEETING.SELECT_MEETING_HOST")
            })
            .regexValidator({
                regExp: "notempty",
                dataType: "enum",
                onError: Ibos.l("MEETING.MEETING_HOST_EMPTY")
            })
            .on("change", function() { $(this).trigger("blur"); });
    }
    // 根据后台设置，会议纪要员是否为必填项
    if (recorderIsNecessary) {
        $("#meeting_minute").formValidator({
                relativeID: "minute_wrap",
                onFocus: Ibos.l("MEETING.SELECT_MEETING_RECORD")
            })
            .regexValidator({
                regExp: "notempty",
                dataType: "enum",
                onError: Ibos.l("MEETING.MEETING_RECORD_EMPTY")
            })
            .on("change", function() { $(this).trigger("blur"); });
    }


    // 根据后台设置，是否忽略预约冲突
    if (!isIgnoreConflict) {
        $("#reserve_status_input").formValidator({
            relativeID: "reserve_status_wrap",
            onFocus: Ibos.l("MEETING.MEETING_CONFLICT")
        }).functionValidator({
            fun: function(txt, elem) {
                return parseInt(txt) ? true : Ibos.l("MEETING.MEETING_CONFLICT");
            },
            onError: Ibos.l("MEETING.MEETING_CONFLICT")
        });
    }

    $("#attend_number").userSelect({
        data: Ibos.data.get("user"),
        type: "user"
    });

    $("#meeting_host").userSelect({
        data: Ibos.data.get("user"),
        type: "user",
        maximumSelectionSize: "1"
    });

    $("#meeting_minute").userSelect({
        data: Ibos.data.get("user"),
        type: "user",
        maximumSelectionSize: "1"
    });

    // 开始日期 结束日期组
    $("#recurring_daterange_btn").daterangepicker({
        format: 'YYYY/MM/DD',
        opens: "right",
        applyClass: "btn-primary",
        locale: {
            applyLabel: Ibos.l("CONFIRM"),
            cancelLabel: Ibos.l("CANCEL"),
            fromLabel: Ibos.l("FROM"),
            toLabel: Ibos.l("TO"),
            weekLabel: 'W',
            customRangeLabel: 'Custom Range',
            daysOfWeek: Ibos.l("DATE.DAYSTR").split(""),
            monthNames: Ibos.l("DATE.MONTHSTR").split(","),
            firstDay: 0
        }
    }, function(start, end, label) {
        $("#recurring_daterange_input").val(start.format('YYYY/MM/DD') + ' - ' + end.format('YYYY/MM/DD'));
        //根据周期性申请时间，判断是否冲突
        Meeting.checkConflictByLoop();
    });

    //周期性申请，开始和结束时间选择器初始化
    $("#recurring_start_time_picker, #recurring_end_time_picker").datepicker({
        pickTime: true,
        pickDate: false,
        pickSeconds: false,
        format: "hh:ii"
    });

    //初始化上传
    Ibos.upload.attach({
        post_params: { module: 'meeting' },
        custom_settings: {
            containerId: "file_target",
            inputId: "attachmentid"
        },
        file_size_limit: "20MB"
    });

    Meeting.initFormInfo();

    var $start = $("#start_time"),
        $end = $("#end_time");

    // 初始化日期控件
    $start.datepicker({
        target: $end,
        pickTime: true,
        pickSeconds: false,
        format: "yyyy-mm-dd hh:ii",
        startDate: new Date
    })
    .on("hide", function(){
        $(this).find("input").trigger("blur");
    });
    // .data('datetimepicker').setEndDate(0);

    $end.datetimepicker({
        pickTime: true,
        pickSeconds: false,
        format: "yyyy-mm-dd hh:ii",
        startDate: new Date
    })
    .on("hide", function(){
        $(this).find("input").trigger("blur");
    });

    //当会议时间改变时，检查是否冲突
    $("#start_time, #end_time").on("hide", function() {
        var roomid = $("#roomid").val();
        //更新会议室预约冲突情;
        Meeting.loadConflictInfo(roomid);
    });

    //根据会议室ID,刷新表单内的数据
    $("#roomid").on("change", function() {
        var roomid = $(this).val();
        Meeting.refreshRoomInfo(roomid);
        //更新会议室预约冲突情;
        Meeting.loadConflictInfo(roomid);
    });


    //是否周期性申请会议室
    $("#recurring_switch").on("change", function() {
        var $this = $(this),
            isOpen = $this.prop("checked"),
            $title = $this.closest(".apply-wrap").find(".title");
        $.formValidator.resetTipState();
        $title.text(isOpen ? "使用" : "不使用");

        $("#time_range_wrap")[isOpen ? "hide" : "show"]();
        $("#recurring_info_wrap")[isOpen ? "show" : "hide"]();

        // 开启周期性会议申请时，正常申请的会议时间不参与验证
        $("#start_time input").unFormValidator(isOpen ? true : false);
        $("#end_time input").unFormValidator(isOpen ? true : false);

        // 设置默认的开始和结束时间
        if (isOpen) {
            var $startTime = $("#recurring_start_time_picker"),
                $endTime = $("#recurring_end_time_picker");
            Meeting.setLoopTime($startTime, $endTime);
        }
    });

    //会议室图片hover时,显示该会议室的座位数，地点等信息
    $("#meeting_picture_wrap").hover(function() {
        var $shade = $("#room_info_shade");
        $shade.stop().animate({ "top": "0" }, 500);
    }, function() {
        var $shade = $("#room_info_shade");
        $shade.stop().animate({ "top": "180px" }, 500);
    });

    // 周期性会议申请，改变重复时间设置
    $("#repeat_type").on("change", function() {
        var type = $(this).val();
        Meeting.setRepeatSelect(type);
    });

    // 通过改变周期性选项, 显示会议冲突
    $("[data-node-type='time']").on("change", function() {
        Meeting.checkConflictByLoop();
    });

    Ibos.evt.add({
        //选择申请的重复日期，可多选
        "applyDay": function(param, elem) {
            var $this = $(this),
                $checkbox = $this.find("input[type='checkbox']"),
                isChecked = $checkbox.prop("checked");
            isChecked ? $this.removeClass("active") : $this.addClass("active");
            $checkbox.prop("checked", !isChecked);
        },
        //选择该会议室提供的设备
        "selectEquipment": function(param, elem) {
            var $this = $(this),
                $checkbox = $this.find("input[type='checkbox']"),
                isChecked = $checkbox.prop("checked");
            isChecked ? $this.removeClass("active") : $this.addClass("active");
            $checkbox.prop("checked", !isChecked);
        },
        //全选该会议室的所有设备
        "selectAllEquiptment": function(param, elem) {
            var $this = $(this),
                $li = $("#equipment_list li"),
                isChecked = $this.prop("checked");
            isChecked ? $li.addClass("active") : $li.removeClass("active");
        },
        //显示该会议室预约信息
        "showAppointment": function(param, elem) {
            $.formValidator.resetTipState();
            var roomid = $("#roomid").val(),
                dialog = Ui.dialog({
                    title: Ibos.l("MEETING.SEE_APPOINTMENT"),
                    id: "d_appointment",
                    padding: 0,
                    cancel: true,
                    width: "580px",
                    cancel: true,
                    lock: true
                });
            Meeting.op.getAppointmentInfo(roomid).done(function(res) {
                dialog.content(res.html);
            });
        }
    });
});
