$(function(){
	var Meeting = {
		op: {
			/**
			 * 实际调整会议室
			 * @method adjustMeeting
			 * @param  {Object} param 传入JSON格式数据
			 * @return {Object}       返回deffered对象
			 */
			"adjustMeeting": function(param){
				var url = Ibos.app.url( "meeting/restmanager/put", {'op' : 'adjust'});
				return $.post(url, param, $.noop, "json");
			},
			/**
			 * 撤销会议室申请
			 * @method revokeMeeting
			 * @param  {Object} param 传入JSON格式数据
			 * @return {Object}       返回deffered对象
			 */
			"revokeMeeting": function(param){
				var url = Ibos.app.url("meeting/restmanager/delete", {'op' : 'getMyMeetings'});
				return $.post(url, param, $.noop, "json");
			},
			/**
			 * 删除会议申请
			 * @method deleteMeeting
			 * @param  {Object} param 传入JSON格式数据
			 * @return {Object}       返回deffered对象
			 */
			"deleteMeeting": function(param){
				var url = Ibos.app.url('meeting/restmanager/delete', {'op' : 'getMyMeetings'});
				return $.post(url, param, $.noop, "json");
			},
			/**
			 * 获取会议室信息
			 * @method deleteMeeting
			 * @param  {Object} param 传入JSON格式数据
			 * @return {Object}       返回deffered对象
			 */
			"getMeetingInfo": function(param){
				var url = Ibos.app.url("meeting/restmanager/get",{'op' : 'getMyMeetings'});
				return $.get(url, param, $.noop, "json");
			},
			/**
			 * 催办会议室申请
			 * @method reminderMeeting
			 * @param  {Object} param 传入JSON格式数据
			 * @return {Object}       返回deffered对象
			 */
			"reminderMeeting": function(param){
				var url = Ibos.app.url("meeting/restmanager/put",{'op' : 'reminders'});
				return $.get(url, param, $.noop, "json");
			},
			/**
			 * 更新会议进行状态的统计数
			 * @method refreshStatusCount
			 * @param  {Object} param 传入JSON格式数据
			 * @return {Object}       返回deffered对象
			 */
			"refreshStatusCount": function(){
				var url = Ibos.app.url("meeting/restmanager/refreshStatusCount");
				return $.get(url, $.noop, "json");
			}
		},
		fun: {
			/**
			 * 格式化时间
			 * @method formatTimeToMilliseconds
			 * @param  {String} val 传入时间值
			 * @return {Number}     返回格式化时间
			 */
			"formatTimeToMilliseconds": function(val){
				var time = val.replace(/-/g, "/"),
					milliseconds = new Date(time).getTime() / 1000;
				return milliseconds;
			},
			/**
			 * 格式化时间
			 * @method formatTimeToHhMm
			 * @param  {String} val 传入时间值
			 * @return {Number}     返回格式化时间
			 */
			"formatTimeToHhMm": function(val){
				var time = new Date(val * 1000),
					hours = time.getHours(),
					fhours = hours >= 10 ? hours : "0" + hours,
					minute = time.getMinutes(),
					fminute = minute >= 10 ? minute : "0" + minute;
				return fhours + ":" + fminute;   
			}
		},
		/** 
		 * "待审核"
		 * @method  changePeendingMeetingView
		 * @param  {Number} start  开始时间
		 * @param  {Number} end    结束时间
		 * @param  {Object} $elem  传入Jquery节点对象
		 */
		"changePeendingMeetingView": function(start, end, $elem){
			var $info = $elem.find(".detailed-info"),
				$reminderBtn = $info.find(".opt-reminder-btn"),
				$meetingName = $info.find(".meeting-title"),
				now = parseInt((new Date().getTime()) / 1000);
			if(end - now >= 0){
				$info.addClass("nostart");
			}else{
				$info.removeClass("nostart").addClass("ended");
				$reminderBtn.hide();
				$meetingName.removeClass("xcbu");
			}

		},
		/** 
		 * 已通过"分类,根据时间变化时, 每项item的功能按钮以及视图的变化
		 * @method  changeAdoptMeetingView
		 * @param  {Number} start  开始时间
		 * @param  {Number} end    结束时间
		 * @param  {Object} $elem  传入Jquery节点对象
		 */
		"changeAdoptMeetingView": function(start, end, $elem){
			var now = parseInt((new Date().getTime()) / 1000),
				start = parseInt(start),
				end = parseInt(end),
				$contentWrap = $elem.find(".meeting-item"),
				$nogoing = $elem.find(".status-nogoing"),
				$going = $elem.find(".status-going"),
				// 倒计时内容
				$timewrap = $going.find(".meeting-last-time"),
				// 当前会议状态，分为未开始 进行中 已结束
				$statusWrap = $elem.find(".mp-status-wrap"),
				$statusTip = $statusWrap.find("i"),
				//功能按钮
				$optBtnWrap = $elem.find('.mm-opt-btnbar'),
				//会议室名称
				$nameWrap = $elem.find(".name-wrap"),
				//会议名称
				$meetingTitle = $contentWrap.find(".meeting-title");

			//获取当前用户的会议角色
			var isApplicant = $contentWrap.hasClass("applicant"), 	//申请人
				isAttender = $contentWrap.hasClass("attender"), 	//出席人员
				isRecorder = $contentWrap.hasClass("recorder"),		//纪要员
				isHoster = $contentWrap.hasClass("hoster");			//主持人

			var nostart = $elem.find("[data-status=nostart]"),		//未开始
				going = $elem.find("[data-status=going]"),			//进行中
				ended = $elem.find("[data-status=ended]");			//已结束

			if(now < start){
				// 当会议未开始时，改变会议状态
				$contentWrap.addClass("nostart");
				// 根据会议状态，改变会议状态标识
				$statusTip.removeClass("on-normal-goning").addClass("on-normal-nostart");
				// 当会议未开始时，隐藏参与人和记录人的功能栏


				//会议结束时，参与人和主持人的功能栏隐藏
				nostart.hide();
				if( !(isAttender || isRecorder) ){
					nostart.show();
				}
				going.hide();
				ended.hide();

			}else if(now == start){
				$(document).trigger("meeting.meetingStart");
			}else if(now > start && now < end){
				// 当会议在进行中时，改变会议状态
				$contentWrap.removeClass("nostart").addClass("going");
				//将会议时间由日期区间切换到倒计时状态
				$nogoing.hide();
				$going.show();
				//开始倒计时
				Meeting.fun.timeCount(start, end, now, $timewrap);
				// 改变右上角的会议状态标识
				$statusTip.removeClass("on-normal-nostart").addClass("on-normal-goning");
				//当会议进行中时，隐藏会议参与人的功能栏


				//会议结束时，参与人和主持人的功能栏隐藏
				going.hide();
				if( !(isAttender || isApplicant) ){
					going.show();
				}
				nostart.hide();
				ended.hide();

			}else if(now == end){
				$(document).trigger("meeting.meetingEnd");
			}else if(now > end){
				// 已结束
				// 当会议结束时，改变会议状态
				$contentWrap.removeClass("going").addClass("ended");
				//当会议结束时，改变会议状态标识，由于记录员比较特殊
				$statusTip.removeClass('on-normal-goning').removeClass('on-normal-nostart');
				if(isRecorder){
					$statusTip.addClass("o-large-minuter");
				}
				// 切换会议倒计时状态到会议时间区间形式
				$nogoing.show();
				$going.hide();
				

				$nameWrap.removeClass("room-name-wrap").addClass("expired-room-tip");
				// 会议结束时，改变会议名称颜色
				$meetingTitle.removeClass("xcbu");

				//会议结束时，参与人和主持人的功能栏隐藏
				nostart.hide();
				going.hide();
				if( isAttender || isHoster ){
					ended.hide();	
				}else if( isApplicant ){
					ended.show();
					ended.children().eq(0).hide().siblings().addClass("opt-revoke-btn");
				}else{
					ended.show();
					if( isRecorder || $contentWrap.hasClass("recorder-hoster") ){
						ended.children().eq(1).hide();
					}
				}
			}
		},
		/** 
		 * 被拒绝"分类,根据时间变化时, 每项item的功能按钮以及视图的变化
		 * @method  changeRefuseMeetingView
		 * @param  {Number} start  开始时间
		 * @param  {Number} end    结束时间
		 * @param  {Object} $elem  传入Jquery节点对象
		 */
		"changeRefuseMeetingView": function(start, end, $elem){
			var $item = $elem.find(".meeting-item"),
				$applyBtn = $item.find(".opt-apply-btn"),
				$meetingName = $item.find(".meeting-title"), 
				now = parseInt((new Date().getTime()) / 1000);
			if(end - now >= 0){
				if(now < start){
					$item.addClass("nostart");
				}else{
					$item.removeClass("nostart").addClass("going");
					$applyBtn.hide();
				}
			}else{
				$item.removeClass("going").addClass("ended");
				$applyBtn.hide();
				$meetingName.removeClass("xcbu");
			}	
		},
		/**
		 * 渲染会议室列表视图
		 * @method renderMeetingView
		 * @param  {Object} $container 传入jquery节点对象
		 * @param  {String} tpl        传入模板ID
		 * @param  {Object} param      传入JSON格式数据
		 */
		"renderMeetingView": function($container, tpl, param){
			var _this = this,
				status = param.status;

			var keywords = Ibos.app.g("keywords"),
				param = keywords ? $.extend(param, {keywords: keywords}) : param;

			// 先解除绑定在每项item上的setinterval的数据
			_this.clearMeetingItem($container);
			// 生成遮罩
			$mainer.waiting(null, "normal", true);
			_this.op.getMeetingInfo(param).done(function(res){
				var data = res.meetings,
					pages = res.pages;
					
				//清空container
				$container.empty();

				$.each(data, function(index, val){
					var itemData = this,
						$elem = _this.creatMeetingItem(itemData, tpl, status, index);
					$container.append($elem);	
				});
				//初始化翻页
				_this.initPagination(pages, status);
				//更新不同分类下的头部提示信息
				_this.refreshStatusTip(res);

				_this.refreshNavActiveStatus(param);
				//初始化冲突信息提示
				$(".warning-tip").tooltip();
				//初始化退回理由
				$(".meeting-role-wrap").tooltip();
				//去掉遮罩
				setTimeout(function(){
					$mainer.waiting(false);
				}, 1010);
			});
			
		},
		/**
		 * 调整窗口初始化
		 * @method adjustDialogInit
		 */
		"adjustDialogInit": function(){
			$("#inside_attender").userSelect({
		        data: Ibos.data.get("user"),
		        type: "user"
		    });

			//初始化日期选择器
		    $('#end_time').datetimepicker({
		        format: 'yyyy-mm-dd hh:ii',//选择后显示的时间格式
		        language: "zh-CN",
		        minView: 2,//选择时间过程中，具体到天，小时或者分钟的最小视图
		        autoclose: true//选择时间后自动关闭
		    });
		},
		/**
		 * 恢复初始化
		 * @method restoreInit
		 */
		"restoreInit": function(){
			$('#end_time').datetimepicker("destroy");
			$(".adjust-info-input").val("");
		},
		/**
		 * 调整会议视图
		 * @param  {Object} $elem 传入jquery节点对象
		 * @param  {Number} time  传入时间
		 */
		"adjustMeetingView": function($elem, time){
			var $contentWrap = $elem.closest(".meeting-item"),
				$nogoingWrap = $contentWrap.find(".status-nogoing"),
				$goingWrap = $contentWrap.find(".status-going"),
				$endTimeWrap = $nogoingWrap.find(".end-time"),
				$topEndTimeWrap = $goingWrap.find(".end-time");
				ftiem = Meeting.fun.formatTimeToHhMm(time);
			$endTimeWrap.text(ftiem);
			$topEndTimeWrap.text(ftiem);
		},
		/**
		 * 刷新会议视图
		 * @param  {Object} $elem 传入jquery节点对象
		 * @param  {Number} time  传入时间
		 */
		"refreshDialogView": function($elem, time){
			var $endTimeWrap = $elem.find(".dialog-end-time"),
				ftime = Meeting.fun.formatTimeToHhMm(time);
			$endTimeWrap.text(ftime);
		},
		/**
		 * 更新会议进行状态的统计数
		 * @method refreshStatusCount
		 * @param  {Object} interval 定时器
		 */
		"refreshStatusCount": function(interval){
			Meeting.op.refreshStatusCount().done(function(res){
				if(res.isSuccess){
					var goingNum = res.going,
						noStartNum = res.nostart;
					$noStartNum.text(noStartNum);
					$goingNum.text(goingNum);
					clearInterval(interval);
				}
			});
		}
	};

	$.extend(true, Meeting, MeetingCommon);

	//搜索功能
	$("#mn_search").search(function(value){
       var $active = $("#review_type_nav>li.active"),
       		status = $active.data("param").status,
       		tpl = Meeting.selectTemplateByStatus(status),
       		param = {status: status, keywords: value};
       	Ibos.app.s({"keywords": value});
   		Meeting.renderMeetingView($container, tpl, param);
    });
    
	var $mainer = $("#mm_list_mainer"),
		$container = $("#meeting_list_wrap"),
		$noStartNum = $("#unstarted_num"),
		$goingNum = $("#ongoing_num"),
		$unapprovedNum = $("#unapproved_num"),
		$passedNum = $("#passed_num"),
		$backedNum = $("#backed_num"),
		isReturn = Ibos.app.g("isReturn"),
		currStatus = Ibos.app.g("status"),
		tpl = Meeting.selectTemplateByStatus(isReturn ? currStatus : 0),
		status = isReturn ? currStatus : 0;
		param = {status: status};
	Meeting.renderMeetingView($container, tpl, param);

	// 监听会议开始的时候，改变视图
	$(document).on("meeting.meetingStart", function(){
		var interval = setTimeout(function(){
			Meeting.refreshStatusCount(interval);
		}, 50);
	});
	// 监听会议结束的时候，改变视图
	$(document).on("meeting.meetingEnd", function(){
		var interval = setTimeout(function(){
			Meeting.refreshStatusCount(interval);
		}, 50);
	});

	Ibos.evt.add({
    	// 切换"待审核", "已通过", "已拒绝"三种分类
		"switchTab": function(param, elem){
			var $this = $(this),
				$lis = $this.closest("ul").find("li"),
				status = param.status,
				tpl = Meeting.selectTemplateByStatus(status),
				param = {status: status};
			$lis.removeClass("active");
			$this.addClass("active");
			Ibos.app.s({"keywords": ""});
			Meeting.renderMeetingView($container, tpl, param);
		},
		// 实际调整会议申请
		"adjustMeeting": function(param, elem, evt){
			var html = $.template("adjust_dialog_tpl", {data: param}),
				$this = $(this),
				$contentWrap = $this.closest(".meeting-item"),
				$timeStemp = $contentWrap.find(".time-stemp");
			Ui.dialog({
				title: Ibos.l("MEETING.ACTUAL_ADJUST"),
				id: "ad_dialog",
				lock: true,
				padding: 0,
				width: 480,
				height: 280,
				content: html,
				init: function(){
					Meeting.adjustDialogInit();
				},
				ok: function(){
					var url = "",
						$form = $("#adjust_info_form"),
						param = $form.serializeArray(),
						time = $("#end_time").val();
					Meeting.op.adjustMeeting(param).done(function(res){
						if(res.isSuccess){
							var nowTiem = Meeting.fun.formatTimeToMilliseconds(time),
								endTime = Meeting.fun.formatTimeToHhMm(nowTiem);
							$timeStemp.data("param").end = nowTiem;
							$this.data("param").endFormatted = endTime;
							$this.attr("data-param", "" + $.toJSON($this.data("param")));
							Meeting.adjustMeetingView($this, nowTiem);
							Meeting.restoreInit();
						}
						Ui.tip(res.msg, res.isSuccess ? "" : "danger");
					});
				},
				cancel: function(){
					Meeting.restoreInit();	
				},
				close: function(){
					Meeting.restoreInit();	
				}
			});
			evt.stopPropagation();
		},
		// 撤销会议申请
		"revokeMeeting": function(param, elem, evt){
			var $this = $(this),
				$currli = $this.closest("li");
			var confirm = Ui.confirm(Ibos.l("MEETING.REVOKE_MEETING_CONFIRM"), function(){
				Meeting.op.revokeMeeting(param).done(function(res){
					if(res.isSuccess){
						var pages = res.data.pages;
						$currli.remove();
						Meeting.refreshMeetingView(pages.curPage, res.data.status);
						Meeting.refreshNavStatusCount(res.data.tabNum);
					}
					Ui.tip(res.msg, res.isSuccess ? "" : "danger");
				});
			});
			evt.stopPropagation();
		},
		// 删除会议申请
		"deleteMeeting": function(param, elem, evt){
			var $this = $(this),
				$currli = $this.closest("li");
			Ui.confirm(Ibos.l("MEETING.DELETE_APPLY_CONFIRM"), function(){
				Meeting.op.deleteMeeting(param).done(function(res){
					if(res.isSuccess){
						var pages = res.data.pages;
						Ui.tip(res.msg);
						$currli.remove();
						Meeting.refreshMeetingView(pages.curPage, res.data.status);
						Meeting.refreshNavStatusCount(res.data.tabNum);
					}else{
						Ui.tip(res.res, "danger");
					}
				});
			});
			evt.stopPropagation();
		},
		// 催办会议室申请
		"reminderMeeting": function(param, elem, evt){
			var $this = $(this),
				$currli = $this.closest("li");
			$currli.waiting(null, "mini", true);
			Meeting.op.reminderMeeting(param).done(function(res){
				res.isSuccess && $currli.waiting(false);
				Ui.tip(res.msg, res.isSuccess ? "" : "danger");
			});
			evt.stopPropagation();
		}
	});
});
